#! /bin/bash

set -e

srcdir="$(pwd)"
builddir="$srcdir/build"
prefix=/tmp/builder-home/install

export QTDIR=$srcdir/qt-copy
export PATH=$QTDIR/bin:$PATH
export LD_LIBRARY_PATH=$QTDIR/lib:$LD_LIBRARY_PATH
export PKG_CONFIG_PATH=$QTDIR/lib:$PKG_CONFIG_PATH

export KDEDIR=$prefix
export PATH=$KDEDIR/bin:$PATH
export LD_LIBRARY_PATH=$KDEDIR/lib:$LD_LIBRARY_PATH
export QT_PLUGIN_PATH=$KDEDIR/lib/kde4/plugins
export KDEDIRS=$KDEDIR

export QTEST_COLORED=1
export KDE_COLOR_DEBUG=1

# may need to be adapted if it's not a debian
export JAVA_HOME=/usr/lib/jvm/java-6-openjdk/

build_cmake() {
    mkdir --parents "$builddir/cmake" 

    (
	cd "$builddir/cmake"
	"$srcdir/cmake-2.6.3/bootstrap" --prefix="$prefix"
	make
	make install
    )
}

build_with_autoconf() {
    subdir="$1"; shift
    (
	cp -a "$srcdir/$subdir" "$builddir/$subdir"
	cd "$builddir/$subdir"
	./configure --prefix="$prefix" "$@"
	make
	make install
    )
}

build_qt_kde() {
    (
	cp -a "$srcdir/qt-kde" "$builddir/qt-kde"
	cd "$builddir/qt-kde"
	echo yes | ./configure -opensource -qt-gif -debug -fast \
	    -no-separate-debug-info -system-libpng -system-libjpeg \
	    -system-zlib -dbus -webkit -plugin-sql-mysql \
	    -nomake examples -nomake demos -platform linux-g++-32 \
	    -prefix $HOME/install
	make
	make install
    )
}

build_kde_component() {
    subdir="$1"; shift

    (
	mkdir --parents "$builddir/$subdir"
	cd "$builddir/$subdir"
	cmake -DCMAKE_INSTALL_PREFIX="$prefix" "$@" "$srcdir/$subdir"
	make
	make install
    )
}

build_cmake 
build_with_autoconf gpgme-1.1.8 --with-gpg=/usr/bin/gpg2 \
    --with-gpgsm=/usr/bin/gpgsm --with-gpgconf=/usr/bin/gpgconf
build_with_autoconf libical-0.43
MAKEFLAGS=j1 build_with_autoconf shared-mime-info-0.60
build_kde_component libssh-0.3.4
build_qt_kde

build_kde_component kdesupport
build_kde_component kdelibs
build_kde_component kdepimlibs
build_kde_component grantlee
build_kde_component kdepim
build_kde_component kdebase \
   -DLIBSSH_LIBRARIES="$prefix"/lib/libssh.so \
   -DLIBSSH_INCLUDE_DIRS="$prefix"/include
